# Prometheux_chain

## Description
Prometheux Chain is a Python SDK designed to help you create, evolve, and deploy knowledge graphs with ease. The SDK offers the following capabilities:

- Data Ingestion: Seamlessly integrate data from various sources, including databases and files.
- Reasoning & Knowledge Augmentation: Perform logical reasoning to derive new insights and augment your existing knowledge base.
- Explainability: Gain clear explanations of the results generated by the system.

For more information refer to the [documentation](https://docs.prometheux.ai/sdk)

## Features
- Supports a wide range of data sources.
- Built-in reasoning engine for deriving new knowledge.
- Easy-to-understand explanations for enhanced interpretability.
- Ready-to-use configurations for fast deployment.

## Installation

### Requirements
- Python 3.7 or higher

### Install Using pip

1. Set Up a Virtual Environment (recommended):

```bash
python3 -m venv myenv
source myenv/bin/activate  # On Windows: myenv\Scripts\activate
```

2. Install the SDK from GitHub:

```bash
pip install git+https://github.com/prometheuxresearch/prometheux_chain.git
````

## Usage 

To perform an evaluation over your .vada file, follow these steps

```python
import prometheux_chain as px
import os

# Set Prometheux configuration
os.environ['PMTX_TOKEN'] = "MyToken"

# Perform evaluation by processing the pmtx-test.vada
results = px.perform("pmtx-test.vada", {"key": "value"})
```

### Example

Here's an example `.vada` file (`pmtx-test.vada`) and how you can use it:

**pmtx-test.vada:**

```prolog
company("Prometheux").
company("Company").

print_pmtx(Name) :- company(Name), Name=${my_company}.
@output("print_pmtx").
```

### Running the Example


```python
results = pmtx.perform("pmtx-test.vada",{"my_company":"Prometheux"})
```
